@@ -2,7 +2,7 @@
 # coding=utf-8
 from pocean.cf import CFDataset
 
-from pocean import logger
+from pocean import logger  # noqa
 
 
 class IndexedRaggedTimeseries(CFDataset):
@@ -35,9 +35,7 @@ class IndexedRaggedTimeseries(CFDataset):
 
         return True
 
-    def from_dataframe(self, df, variable_attributes=None, global_attributes=None):
-        variable_attributes = variable_attributes or {}
-        global_attributes = global_attributes or {}
+    def from_dataframe(cls, df, output, **kwargs):
         raise NotImplementedError
 
     def calculated_metadata(self, df=None, geometries=True, clean_cols=True, clean_rows=True):
